@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -13,7 +13,7 @@ with qw(
   Dist::Zilla::Role::PluginBundle::Easy
 );
 
-sub mvp_multivalue_args { return qw/stopwords/ }
+sub mvp_multivalue_args { return qw(stopwords travis_ci_ignore_perl) }
 
 has stopwords => (
     is      => 'ro',
@@ -24,6 +24,15 @@ has stopwords => (
     },
 );
 
+has travis_ci_ignore_perl => (
+    is      => 'ro',
+    isa     => 'Maybe[ArrayRef]',
+    lazy    => 1,
+    default => sub {
+        exists $_[0]->payload->{travis_ci_ignore_perl} ? $_[0]->payload->{travis_ci_ignore_perl} : undef;
+    },
+);
+
 sub configure {
     my $self = shift;
 
@@ -38,9 +47,12 @@ sub configure {
             }
         ],
 
+        'Author::SKIRMESS::Test::XT::Test::Changes',
+        'Author::SKIRMESS::Test::XT::Test::CleanNamespaces',
         'Author::SKIRMESS::Test::XT::Test::CPAN::Meta',
         'Author::SKIRMESS::Test::XT::Test::CPAN::Meta::JSON',
         'Author::SKIRMESS::Test::XT::Test::DistManifest',
+        'Author::SKIRMESS::Test::XT::Test::EOL',
         'Author::SKIRMESS::Test::XT::Test::Kwalitee',
         'Author::SKIRMESS::Test::XT::Test::MinimumVersion',
         'Author::SKIRMESS::Test::XT::Test::Mojibake',
@@ -52,6 +64,15 @@ sub configure {
         [ 'Author::SKIRMESS::Test::XT::Test::Spelling', { stopwords => $self->stopwords } ],
         'Author::SKIRMESS::Test::XT::Test::Version',
 
+        [
+            'Author::SKIRMESS::TravisCI',
+            {
+                travis_ci_ignore_perl => $self->travis_ci_ignore_perl,
+            }
+        ],
+
+        'Author::SKIRMESS::Perl::Tidy::RC',
+
         # Check at build/release time if modules are out of date
         [
             'PromptIfStale', 'stale modules, release',
@@ -115,7 +136,7 @@ sub configure {
         [
             'PruneCruft',
             {
-                except => [qw( \.perltidyrc )],
+                except => [qw( \.perlcriticrc \.perltidyrc )],
             }
         ],
 
